==> 0.1.0.zip: buzzword-bingo/src/app/components/bingocontroller.tsx <==
'use client';

import React from 'react'
import Bingo from './bingo'

function FisherYatesShuffle(array:string[]):string[]{
	for(let i = array.length - 1; i > 0; i--){
		const j = Math.floor(Math.random() * (i + 1));
		const temp = array[i];
		array[i] = array[j];
		array[j] = temp;
	}
	return array;
}

export default function BingoController(){
	const [size, setSize] = React.useState(5);
	const buzzwords = ["Cloud", "Cyber-[Something]", "Distrupt[ive]", "AI", "Meta [Something]", "Gamification", "Web 2.0/3.0", "Industry 4.0", "Internet of Things", "Multiexperience", "Big Data", "Crypto", "[Something] as a service", "Emerging [Something]", "Streamline", "Ecosystem", "Leverage", "Outside the Box", "Pivot", "Strategic", "Agile", "Smart Tech", "Data Warehouse", "Actionable Insights", "Holistic Approach", "Digital Transformation", "Growth Hacking"];
	const [items, setItems] = React.useState(buzzwords);
	const sizeError = (items.length < size);
	return(
		<>
		<div className="w-3/4 flex flex-row m-auto">
		<Bingo size={size} items={items}/>
		<form className="w-1/3">
		<input type="range" min={3} max={5} value={size} className="range range-primary" step={1} onChange={({target:{value:s}}) => setSize(+s)}/>
		<div className="w-full flex justify-between text-xs px-2">
			<span>3x3</span>
			<span>4x4</span>
			<span>5x5</span>
		</div>
		<a className="btn btn-primary" onClick={() => setItems(FisherYatesShuffle(buzzwords))}>Regenerate</a>
		</form>
		</div>
		{sizeError && <div className="alert alert-warning"><svg xmlns="http://www.w3.org/2000/svg" className="stroke-current shrink-0 h-6 w-6" fill="none" viewBox="0 0 24 24"><path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M12 9v2m0 4h.01m-6.938 4h13.856c1.54 0 2.502-1.667 1.732-3L13.732 4c-.77-1.333-2.694-1.333-3.464 0L3.34 16c-.77 1.333.192 3 1.732 3z" /></svg><span>Warning: Mismatch between item count and size</span></div>}
		</>
	);
}

==> 0.2.0.zip: buzzword-bingo/src/app/components/bingocontroller.tsx <==
'use client';

import React from 'react'
import Bingo from './bingo'

function FisherYatesShuffle(array:string[]):string[]{
	for(let i = array.length - 1; i > 0; i--){
		const j = Math.floor(Math.random() * (i + 1));
		const temp = array[i];
		array[i] = array[j];
		array[j] = temp;
	}
	return array;
}

export default function BingoController(){
	const [size, setSize] = React.useState(5);
	const buzzwords = ["Cloud", "Cyber-[Something]", "Distrupt[ive]", "AI", "Meta [Something]", "Gamification", "Web 2.0/3.0", "Industry 4.0", "Internet of Things", "Multiexperience", "Big Data", "Crypto", "[Something] as a service", "Emerging [Something]", "Streamline", "Ecosystem", "Leverage", "Outside the Box", "Pivot", "Strategic", "Agile", "Smart Tech", "Data Warehouse", "Actionable Insights", "Holistic Approach", "Digital Transformation", "Growth Hacking"];
	const [items, setItems] = React.useState(buzzwords);
	const sizeError = (items.length < size);
	return(
		<>
		<div className="w-3/4 flex flex-col m-auto gap-4">
		<Bingo size={size} items={items}/>
		<form className="w-1/3 m-auto">
		<input type="range" min={3} max={5} value={size} className="range range-secondary" step={1} onChange={({target:{value:s}}) => setSize(+s)}/>
		<div className="w-full flex justify-between text-xs px-2">
			<span>3x3</span>
			<span>4x4</span>
			<span>5x5</span>
		</div>
		<a className="btn btn-secondary" onClick={() => setItems(FisherYatesShuffle(buzzwords))}>Regenerate</a>
		</form>
		</div>
		{sizeError && <div className="alert alert-warning"><svg xmlns="http://www.w3.org/2000/svg" className="stroke-current shrink-0 h-6 w-6" fill="none" viewBox="0 0 24 24"><path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M12 9v2m0 4h.01m-6.938 4h13.856c1.54 0 2.502-1.667 1.732-3L13.732 4c-.77-1.333-2.694-1.333-3.464 0L3.34 16c-.77 1.333.192 3 1.732 3z" /></svg><span>Warning: Mismatch between item count and size</span></div>}
		</>
	);
}
